#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-I04 (C) COPYRIGHT International Business Machines Corp., 1997,2009
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# ifix launcher

FIXID=LI74939

thisHostname=`hostname -s`
thisDir=`dirname "$0"`
errorsduringinstall=0

if [ ! "$2" ]
then
  if [  -f ./$FIXID.sh ]
 then
 echo "Ifix_$FIXID: WVS Ifix $FIXID Installer command syntax: "
 echo " to install ifix  syntax: ifix_$FIXID -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_$FIXID.sh -uninstall "
 echo " "
 exit -1
 fi
fi

if [ $# -eq 0 ]
then
 echo "Ifix_$FIXID: WVS Ifix $FIXID Installer command syntax: "
 echo " to install ifix  syntax: ifix_$FIXID -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_$FIXID.sh -uninstall "
 echo " "
 exit -1
fi


if [ -f /opt/IBM/WebSphere/AppServer/profiles/AppSrv01/bin/setupCmdLine.sh ]
then
   source /opt/IBM/WebSphere/AppServer/profiles/AppSrv01/bin/setupCmdLine.sh
fi

if [ ! "$WAS_HOME" ] ; then
   echo "Ifix_$FIXID: Please run WebSphere Application Server's setupCmdLine.sh to setup"
   echo "         the WAS Command line environment"
  exit -1
fi

if [ ! "$WVS_ROOT" ] ; then
   echo "Ifix_$FIXID: Please configure WebSphere Voice Server wvs.setenv according"
   echo "         to the WVS InfoCenter "
  exit -1
fi


isInstallOption=false
isUnInstallOption=false
nonJavaOptionCount=1
for option in "$@" ; do
  if [ "$option" = "-install" ] ; then
     isInstallOption=true
  else
     if [ "$option" = "-uninstall" ] ; then
        isUnInstallOption=true
     fi
  fi
done

if [ "$isInstallOption" = "true" ] ; then
  if [ -f $WVS_ROOT/ifix/$FIXID/wvsapp.ear.bak ] ; then
    echo "Ifix_$FIXID: Ifix $FIXID is applied, please uninstall before trying to reinstall ifix"
    exit -1
  fi
fi

if [ "$isInstallOption" = "true" ] ; then
 # Check that the ifix files are found
 echo "Ifix_$FIXID: Checking for ifix files ..."
  if [ -f $thisDir/wvsapp.ear ] ; then
    if [ -f $thisDir/wvsapp.ear ] ; then
      echo "Ifix_$FIXID: Ifix files found.. proceeding to install ifix"
      mkdir -p $WVS_ROOT/ifix/$FIXID
      cp -p $thisDir/$FIXID.sh $WVS_ROOT/ifix/ifix_$FIXID.sh
      cp -p $thisDir/stopVoiceServer.jacl $WVS_ROOT/ifix/$FIXID/stopVoiceServer.jacl
      cp -p $thisDir/installEar.jacl $WVS_ROOT/ifix/$FIXID/installEar.jacl
      cp -p $WVS_ROOT/ear/wvsapp.ear $WVS_ROOT/ifix/$FIXID/wvsapp.ear.bak
      cp -p $WVS_ROOT/ViaVoice/bin/libibmgram.so $WVS_ROOT/ifix/$FIXID/libibmgram.so.bak

      # Backup SIV config files ----------------------------------------------------
      echo "Ifix_$FIXID: Backing up SIV config files..."
      echo "Ifix_$FIXID: Backing up SIV config files..." >> $WVS_ROOT/log/$FIXID.log
      mkdir -p $WVS_ROOT/ifix/$FIXID/confbck >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsweb.war/WEB-INF/ibm-web-bnd.xmi $WVS_ROOT/ifix/$FIXID/confbck >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsweb.war/WEB-INF/web.xml $WVS_ROOT/ifix/$FIXID/confbck >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsejb.jar/META-INF/ibm-ejb-jar-bnd.xmi $WVS_ROOT/ifix/$FIXID/confbck >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsejb.jar/META-INF/ejb-jar.xml $WVS_ROOT/ifix/$FIXID/confbck >> $WVS_ROOT/log/$FIXID.log
      echo "Ifix_$FIXID: SIV config backup complete."
     echo "Ifix_$FIXID: SIV config backup complete." >> $WVS_ROOT/log/$FIXID.log
      # ----------------------------------------------------------------------------

      echo "Ifix_$FIXID: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_$FIXID: Application Server stopped successful, proceeding to install ifix"
      else
         echo "Ifix_$FIXID: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/$FIXID
         exit -1
      fi

      cp -fbp $thisDir/wvsapp.ear $WVS_ROOT/ear/.
      cp -fbp $thisDir/libibmgram.so $WVS_ROOT/ViaVoice/bin/.
      chmod 755 $WVS_ROOT/ear/wvsapp.ear
      chmod 755 $WVS_ROOT/ViaVoice/bin/libibmgram.so

      echo "Ifix_$FIXID: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_$FIXID: Application Server started successful, proceeding to install ifix"
      else
         echo "Ifix_$FIXID: Application Server reported failure during starting. Ifix installation was not successful. Please uninstall"
         exit -1
      fi

      echo "Ifix_$FIXID: Stopping  WebSphere Voice Server"
      $WAS_HOME/bin/wsadmin.sh -f $thisDir/stopVoiceServer.jacl "$thisHostname"Node01
      errorsduringinstall=$?

      echo "Ifix_$FIXID: Updating WebSphere Voice Server J2EE Application"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/ifix/$FIXID/installEar.jacl $WVS_ROOT/ear wvsapp WVS-"$thisHostname"Node01 "$thisHostname"Node01
      errorsduringinstall=$?

      # Restore SIV config files ---------------------------------------------------
      echo "Ifix_$FIXID: Restoring SIV config files..."
      echo "Ifix_$FIXID: Restoring SIV config files..." >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WVS_ROOT/ifix/$FIXID/confbck/ibm-web-bnd.xmi  $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsweb.war/WEB-INF >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WVS_ROOT/ifix/$FIXID/confbck/web.xml $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsweb.war/WEB-INF >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WVS_ROOT/ifix/$FIXID/confbck/ibm-ejb-jar-bnd.xmi $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsejb.jar/META-INF >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WVS_ROOT/ifix/$FIXID/confbck/ejb-jar.xml $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsejb.jar/META-INF >> $WVS_ROOT/log/$FIXID.log

      rm -rf $WVS_ROOT/ifix/$FIXID/confbck >> $WVS_ROOT/log/$FIXID.log
      echo "Ifix_$FIXID: SIV config files restored."
      echo "Ifix_$FIXID: SIV config files restored." >> $WVS_ROOT/log/$FIXID.log
      # ----------------------------------------------------------------------------
      
      if [ $errorsduringinstall = "0" ] ; then
        echo "Ifix_$FIXID: Ifix is now applied, please reboot the system"
      else
        echo "Ifix_$FIXID: Ifix installation was not successful. Please uninstall. "
      fi

     else
      echo "Ifix_$FIXID: Ifix files missing, please be sure this script is in same directory as the binary files"
    fi
  fi
  cp -fp $thisDir/$FIXID.log $WVS_ROOT/log/.
fi

if [ "$isUnInstallOption" = "true" ] ; then
 # Check that the ifix backup files are found
 echo "Ifix_$FIXID: Checking for ifix backup files ..."
  if [ -f $WVS_ROOT/ifix/$FIXID/wvsapp.ear.bak ] ; then
    if [ -f $WVS_ROOT/ifix/$FIXID/wvsapp.ear.bak ] ; then
      echo "Ifix_$FIXID: Ifix backup files found.. proceeding to un-install ifix"


      echo "Ifix_$FIXID: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_$FIXID: Application Server stopped successful, proceeding to uninstall ifix"
      else
         echo "Ifix_$FIXID: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/$FIXID
         exit -1
      fi

      cp -fp $WVS_ROOT/ifix/$FIXID/wvsapp.ear.bak  $WVS_ROOT/ear/wvsapp.ear
      cp -fp $WVS_ROOT/ifix/$FIXID/libibmgram.so.bak  $WVS_ROOT/ViaVoice/bin/libibmgram.so
      chmod 755 $WVS_ROOT/ear/wvsapp.ear
      chmod 755 $WVS_ROOT/ViaVoice/bin/libibmgram.so

      # Backup SIV config files ----------------------------------------------------
      echo "Ifix_$FIXID: Backing up SIV config files..."
      echo "Ifix_$FIXID: Backing up SIV config files..." >> $WVS_ROOT/log/$FIXID.log
      mkdir -p $WVS_ROOT/ifix/$FIXID/confbck >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsweb.war/WEB-INF/ibm-web-bnd.xmi $WVS_ROOT/ifix/$FIXID/confbck >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsweb.war/WEB-INF/web.xml $WVS_ROOT/ifix/$FIXID/confbck >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsejb.jar/META-INF/ibm-ejb-jar-bnd.xmi $WVS_ROOT/ifix/$FIXID/confbck >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsejb.jar/META-INF/ejb-jar.xml $WVS_ROOT/ifix/$FIXID/confbck >> $WVS_ROOT/log/$FIXID.log
      echo "Ifix_$FIXID: SIV config backup complete."
      echo "Ifix_$FIXID: SIV config backup complete." >> $WVS_ROOT/log/$FIXID.log
      # ----------------------------------------------------------------------------

      echo "Ifix_$FIXID: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_$FIXID: Application Server started successful, proceeding to uninstall ifix"
      else
         echo "Ifix_$FIXID: Application Server reported failure during starting. Ifix uninstallation was not successful. Please contact support"
         exit -1
      fi


      echo "Ifix_$FIXID: Stopping  WebSphere Voice Server"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/ifix/$FIXID/stopVoiceServer.jacl "$thisHostname"Node01
      errorsduringinstall=$?

      echo "Ifix_$FIXID: Updating WebSphere Voice Server J2EE Application"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/ifix/$FIXID/installEar.jacl $WVS_ROOT/ear wvsapp WVS-"$thisHostname"Node01 "$thisHostname"Node01
      errorsduringinstall=$?

      # Restore SIV config files ---------------------------------------------------
      echo "Ifix_$FIXID: Restoring SIV config files..."
      echo "Ifix_$FIXID: Restoring SIV config files..." >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WVS_ROOT/ifix/$FIXID/confbck/ibm-web-bnd.xmi  $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsweb.war/WEB-INF >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WVS_ROOT/ifix/$FIXID/confbck/web.xml $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsweb.war/WEB-INF >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WVS_ROOT/ifix/$FIXID/confbck/ibm-ejb-jar-bnd.xmi $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsejb.jar/META-INF >> $WVS_ROOT/log/$FIXID.log
      cp -fp $WVS_ROOT/ifix/$FIXID/confbck/ejb-jar.xml $WAS_HOME/profiles/AppSrv01/config/cells/$WAS_CELL/applications/WVS-$WAS_NODE.ear/deployments/WVS-$WAS_NODE/wvsejb.jar/META-INF >> $WVS_ROOT/log/$FIXID.log

      rm -rf $WVS_ROOT/ifix/$FIXID/confbck >> $WVS_ROOT/log/$FIXID.log
      echo "Ifix_$FIXID: SIV config files restored."
      echo "Ifix_$FIXID: SIV config files restored." >> $WVS_ROOT/log/$FIXID.log
      # ----------------------------------------------------------------------------

      if [ $errorsduringinstall = "0" ] ; then
        echo "Ifix_$FIXID: Ifix is now uninstalled, please reboot the system"
        echo "Ifix_$FIXID:  Please remove the $WVS_ROOT/ifix/$FIXID directory before attempting a subsequent install of this ifix."
      else
        echo "Ifix_$FIXID: Ifix uninstallation was not successful. Please contact support. "
      fi

    else
      echo "Ifix_$FIXID: Ifix backup files missing, uninstall not performed"
    fi
  else
    echo "Ifix_$FIXID: Ifix backup files missing, uninstall not performed"
  fi
fi
exit $?
